@@ -16,7 +16,7 @@ FUEL = [autogas, diesel, erdgas, superplus, super, normal]
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.13"
+        self.version = "1.0.14"
         self.author = "Ludy87"
         self.project = "Ich tanke billig"
         self.page = "https://www.astra-g.org/"
@@ -175,7 +175,7 @@ def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = -1):
                         "fuel": kraftstoff,
                         "pos": i +1,
                     }
-                    if limit == i & limit != -1:
+                    if limit == i and limit != -1:
                         break
                     i += 1
                     if (FUEL[FUEL.index(kraftstoff)] == FUEL[0]):
